@@ -11,7 +11,7 @@
 #                                                              |_|       
 
 __title__   = 'coinmarketcap'
-__version__ = '0.4.1'
+__version__ = '0.5'
 __author__  = '@c0ding'
 __repo__    = 'https://github.com/c0ding/coinmarketcap-api'
 __license__ = 'Apache v2.0 License'
@@ -19,6 +19,6 @@ __license__ = 'Apache v2.0 License'
 import coinmarketcap_utils
 from coinmarketcap_api import (
 	about, rank, name, short, market_cap, price, coin_supply, market_volume,
-	cap_change_1h, cap_change_24h, cap_change_7d, last_updated, total_market_cap,
-	stats, coin_summary
+	cap_change_1h, cap_change_24h, cap_change_7d, mineable, last_updated,
+	total_market_cap, stats, coin_summary
 )
