@@ -7,7 +7,7 @@ from coinmarketcap_utils import market_cap_info
 from coinmarketcap_utils import coinmarketcap_info
 
 __title__   = 'coinmarketcap'
-__version__ = '0.4.1'
+__version__ = '0.5'
 __author__  = '@c0ding'
 __repo__    = 'https://github.com/c0ding/coinmarketcap-api'
 __license__ = 'Apache v2.0 License'
@@ -18,7 +18,7 @@ def about():
 
 	return '{} v.{} is maintained by {} and available at {}.'.format(__title__, __version__, __author__, __repo__)
 
-	
+
 def rank(PARAMETER):
 	return coin_info(PARAMETER)[0]
 
@@ -58,7 +58,15 @@ def cap_change_24h(PARAMETER):
 def cap_change_7d(PARAMETER):
 	return coin_info(PARAMETER)[9]
 
-	
+
+def mineable(PARAMETER):
+	try:
+		if coin_info(PARAMETER)[10] == '*':
+			return 'false'
+	except IndexError:
+		return 'true'
+
+
 def last_updated():
 	return update_info()[0]
 
@@ -70,13 +78,14 @@ def total_market_cap():
 def stats():
 	return str(coinmarketcap_info()['active_crypto_currencies']) + ' Currencies / '\
 	+ str(coinmarketcap_info()['active_markets']) + ' Markets'
-	
+
+
 def coin_summary(PARAMETER):
 	keys = ['name', 'rank', 'short', 'market_cap', 'market_volume', 'cap_change_1h',\
-	'cap_change_24h', 'cap_change_7d', 'price', 'coin_supply']
+	'cap_change_24h', 'cap_change_7d', 'price', 'coin_supply', 'mineable']
 	values = [name(PARAMETER), rank(PARAMETER), short(PARAMETER), market_cap(PARAMETER),\
 	market_volume(PARAMETER), cap_change_1h(PARAMETER), cap_change_24h(PARAMETER),\
-	cap_change_7d(PARAMETER), price(PARAMETER), coin_supply(PARAMETER)]
+	cap_change_7d(PARAMETER), price(PARAMETER), coin_supply(PARAMETER), mineable(PARAMETER)]
 	coin_summary_info = {}
 	for i in range(len(keys)):
 	    coin_summary_info[keys[i]] = values[i]
