@@ -6,7 +6,7 @@ import urllib
 import lxml.html
 
 __title__   = 'coinmarketcap'
-__version__ = '0.4.1'
+__version__ = '0.5'
 __author__  = '@c0ding'
 __repo__    = 'https://github.com/c0ding/coinmarketcap-api'
 __license__ = 'Apache v2.0 License'
@@ -18,9 +18,11 @@ def coin_info(PARAMETER):
 	tree = raw_data.xpath('//tr[@id="id-' + PARAMETER + '"]/td//text()')
 	clean_space = map(lambda x: x.strip(), tree)
 	coin_details = [x for x in clean_space if x]
-	unwanted_char = '*'
-	if unwanted_char in coin_details:
-		coin_details.remove(unwanted_char)
+	mineable_char = '*'
+	if mineable_char in coin_details:
+		coin_details.remove(mineable_char)
+		mineable_index = len(coin_details)
+		coin_details.insert(mineable_index, mineable_char)
 	return coin_details
 
 
